summaryrefslogtreecommitdiffstats
path: root/lib/public
diff options
context:
space:
mode:
authorChristoph Wurst <christoph@winzerhof-wurst.at>2017-01-09 21:29:59 +0100
committerChristoph Wurst <christoph@winzerhof-wurst.at>2017-01-09 21:29:59 +0100
commitfe6416072d417b6ef166695008d9f94f07775dc9 (patch)
treeec8df2472f2a51db19e1028babac4cdde857b5d0 /lib/public
parent9a5b9d8555c89293073af17f8a2c1ebf3c64de8d (diff)
downloadnextcloud-server-fe6416072d417b6ef166695008d9f94f07775dc9.tar.gz
nextcloud-server-fe6416072d417b6ef166695008d9f94f07775dc9.zip
set 'no-store' cache header if we do not want FF to cache
Signed-off-by: Christoph Wurst <christoph@winzerhof-wurst.at>
Diffstat (limited to 'lib/public')
-rw-r--r--lib/public/AppFramework/Http/Response.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/public/AppFramework/Http/Response.php b/lib/public/AppFramework/Http/Response.php
index 8591d6abc68..051e68f3144 100644
--- a/lib/public/AppFramework/Http/Response.php
+++ b/lib/public/AppFramework/Http/Response.php
@@ -43,11 +43,11 @@ use OCP\AppFramework\Http;
class Response {
/**
* Headers - defaults to ['Cache-Control' => 'no-cache, must-revalidate']
* @var array
*/
private $headers = array(
- 'Cache-Control' => 'no-cache, must-revalidate'
+ 'Cache-Control' => 'no-cache, no-store, must-revalidate'
);
@@ -43,11 +43,11 @@ use OCP\AppFramework\Http;
class Response {
/**
- * Headers - defaults to ['Cache-Control' => 'no-cache, must-revalidate']
+ * Headers - defaults to ['Cache-Control' => 'no-cache, no-store, must-revalidate']
* @var array
*/